Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FormatFailureError ¶
FormatFailureError returns a summary error for failed operations, or nil if there are no failures. Each entry in failures should be a pre-formatted line.
func MaxWorkers ¶
MaxWorkers returns the bounded number of concurrent workers to use. Falls back to runtime.NumCPU() when configured is 0, and caps at total. The minimum return value is 1.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.